The "source_mspct" object named filters_UVIVIF.mspct
contains a collection of "source_spct" objects with spectral
fluorescence emission data for filters illuminated with ultraviolet-A
radiation at 365 nm.
The variables in each member spectrum are as follows:
These member objects contain metadata stored as R attributes. Accessors are
available to the metadata: what_measured(), how_measured(),
when_measured(), filter_properties() and comment().
The member spectra are
named consistently with the transmittance spectra in the collection
filters.mspct. Currently all members of
filters_UVIVIF.mspct are ionic glass photography filters.